@@ -304,6 +304,8 @@ class DeviceMetricView(GenericAPIView):
         return tags
 
     def _get_mobile_signal_type(self, signal):
+        if not signal:
+            return
         # if only one access technology in use, return that
         sections = list(signal.keys())
         if len(sections) == 1:
@@ -317,7 +319,9 @@ class DeviceMetricView(GenericAPIView):
                 return tech
 
     def _write_mobile_signal(self, interface, ifname, ct, pk, current=False, time=None):
-        access_type = self._get_mobile_signal_type(interface['mobile']['signal'])
+        access_type = self._get_mobile_signal_type(interface['mobile'].get('signal'))
+        if not access_type:
+            return
         data = interface['mobile']['signal'][access_type]
         signal_power = signal_strength = None
         extra_values = {}
